==> tuia-advert-center-api-2.2.18-sources.jar: cn/com/duiba/tuia/core/api/dto/rsp/app/RspAppFlowStrategyPage.java <==
/**
 * Project Name:manager-domain<br>
 * File Name:AppDataRsp.java<br>
 * Package Name:cn.com.duiba.tuia.manager.rsp<br>
 * Date:2016年10月26日下午8:01:24<br>
 * Copyright (c) 2016, duiba.com.cn All Rights Reserved.<br>
 */

package cn.com.duiba.tuia.core.api.dto.rsp.app;

import org.apache.commons.lang.builder.ToStringBuilder;

import java.io.Serializable;

/**
 * 新媒体流量策略信息 date: 2017年4月18日 上午10:56:50 <br/>
 *
 * @author chencheng
 * @version
 */
public class RspAppFlowStrategyPage implements Serializable {

    private static final long serialVersionUID = 7436064408821775463L;

    /** 开发者id. */
    private Long              developerId;

    /** 开发者账号. */
    private String            developerAccount;

    /** 应用id. */
    private Long              appId;

    /** 应用名称. */
    private String            appName;

    /**
     * 标签名称
     */
    private String tagName;

    /** app来源 0-来自兑吧，1-来自媒体平台 */
    private Integer           appSource;

    /** 策略开关(0表示关，1表示开). */
    private Integer           switchStrategy;

    /** 总广告数 */
    private Integer           totalAdvertNum;

    /** 遍历数 */
    private Long              traversalNum;

    /** 有效广告数8 */
    private Integer           effectAdvertNum;

    public Integer getTotalAdvertNum() {
        return totalAdvertNum;
    }

    public void setTotalAdvertNum(Integer totalAdvertNum) {
        this.totalAdvertNum = totalAdvertNum;
    }

    public Long getTraversalNum() {
        return traversalNum;
    }

    public void setTraversalNum(Long traversalNum) {
        this.traversalNum = traversalNum;
    }

    public Integer getEffectAdvertNum() {
        return effectAdvertNum;
    }

    public void setEffectAdvertNum(Integer effectAdvertNum) {
        this.effectAdvertNum = effectAdvertNum;
    }

    /**
     * appName.
     *
     * @return the appName
     */
    public String getAppName() {
        return appName;
    }

    /**
     * appName.
     *
     * @param appName the appName to set
     */
    public void setAppName(String appName) {
        this.appName = appName;
    }

    /**
     * developerId.
     *
     * @return the developerId
     */
    public Long getDeveloperId() {
        return developerId;
    }

    /**
     * developerId.
     *
     * @param developerId the developerId to set
     */
    public void setDeveloperId(Long developerId) {
        this.developerId = developerId;
    }

    /**
     * developerAccount.
     *
     * @return the developerAccount
     */
    public String getDeveloperAccount() {
        return developerAccount;
    }

    /**
     * developerAccount.
     *
     * @param developerAccount the developerAccount to set
     */
    public void setDeveloperAccount(String developerAccount) {
        this.developerAccount = developerAccount;
    }

    /**
     * appId.
     *
     * @return the appId
     */
    public Long getAppId() {
        return appId;
    }

    /**
     * appId.
     *
     * @param appId the appId to set
     */
    public void setAppId(Long appId) {
        this.appId = appId;
    }

    /**
     * appSource.
     *
     * @return the appSource
     */
    public Integer getAppSource() {
        return appSource;
    }

    /**
     * appSource.
     *
     * @param appSource the appSource to set
     */
    public void setAppSource(Integer appSource) {
        this.appSource = appSource;
    }

    /**
     * switchStrategy.
     *
     * @return the switchStrategy
     */
    public Integer getSwitchStrategy() {
        return switchStrategy;
    }

    /**
     * switchStrategy.
     *
     * @param switchStrategy the switchStrategy to set
     */
    public void setSwitchStrategy(Integer switchStrategy) {
        this.switchStrategy = switchStrategy;
    }

    public String getTagName() {
        return tagName;
    }

    public void setTagName(String tagName) {
        this.tagName = tagName;
    }

    /**
     * To string.
     *
     * @return the string
     */
    @Override
    public String toString() {
        return ToStringBuilder.reflectionToString(this);
    }

}

==> tuia-advert-center-api-2.4.49-sources.jar: cn/com/duiba/tuia/core/api/dto/rsp/app/RspAppFlowStrategyPage.java <==
/**
 * Project Name:manager-domain<br>
 * File Name:AppDataRsp.java<br>
 * Package Name:cn.com.duiba.tuia.manager.rsp<br>
 * Date:2016年10月26日下午8:01:24<br>
 * Copyright (c) 2016, duiba.com.cn All Rights Reserved.<br>
 */

package cn.com.duiba.tuia.core.api.dto.rsp.app;

import org.apache.commons.lang.builder.ToStringBuilder;

import java.io.Serializable;

/**
 * 新媒体流量策略信息 date: 2017年4月18日 上午10:56:50 <br/>
 *
 * @author chencheng
 * @version
 */
public class RspAppFlowStrategyPage implements Serializable {

    private static final long serialVersionUID = 7436064408821775463L;

    /** 开发者id. */
    private Long              developerId;

    /** 开发者账号. */
    private String            developerAccount;

    /** 应用id. */
    private Long              appId;

    /** 应用名称. */
    private String            appName;

    /**
     * 标签名称
     */
    private String tagName;

    /** app来源 0-来自兑吧，1-来自媒体平台 */
    private Integer           appSource;

    /** 策略开关(0表示关，1表示开). */
    private Integer           switchStrategy;

    /** 总广告数 */
    private Integer           totalAdvertNum = 0;

    /** 遍历数 */
    private Long              traversalNum;

    /** 有效广告数8 */
    private Integer           effectAdvertNum = 0;

    public Integer getTotalAdvertNum() {
        return totalAdvertNum;
    }

    public void setTotalAdvertNum(Integer totalAdvertNum) {
        this.totalAdvertNum = totalAdvertNum;
    }

    public Long getTraversalNum() {
        return traversalNum;
    }

    public void setTraversalNum(Long traversalNum) {
        this.traversalNum = traversalNum;
    }

    public Integer getEffectAdvertNum() {
        return effectAdvertNum;
    }

    public void setEffectAdvertNum(Integer effectAdvertNum) {
        this.effectAdvertNum = effectAdvertNum;
    }

    /**
     * appName.
     *
     * @return the appName
     */
    public String getAppName() {
        return appName;
    }

    /**
     * appName.
     *
     * @param appName the appName to set
     */
    public void setAppName(String appName) {
        this.appName = appName;
    }

    /**
     * developerId.
     *
     * @return the developerId
     */
    public Long getDeveloperId() {
        return developerId;
    }

    /**
     * developerId.
     *
     * @param developerId the developerId to set
     */
    public void setDeveloperId(Long developerId) {
        this.developerId = developerId;
    }

    /**
     * developerAccount.
     *
     * @return the developerAccount
     */
    public String getDeveloperAccount() {
        return developerAccount;
    }

    /**
     * developerAccount.
     *
     * @param developerAccount the developerAccount to set
     */
    public void setDeveloperAccount(String developerAccount) {
        this.developerAccount = developerAccount;
    }

    /**
     * appId.
     *
     * @return the appId
     */
    public Long getAppId() {
        return appId;
    }

    /**
     * appId.
     *
     * @param appId the appId to set
     */
    public void setAppId(Long appId) {
        this.appId = appId;
    }

    /**
     * appSource.
     *
     * @return the appSource
     */
    public Integer getAppSource() {
        return appSource;
    }

    /**
     * appSource.
     *
     * @param appSource the appSource to set
     */
    public void setAppSource(Integer appSource) {
        this.appSource = appSource;
    }

    /**
     * switchStrategy.
     *
     * @return the switchStrategy
     */
    public Integer getSwitchStrategy() {
        return switchStrategy;
    }

    /**
     * switchStrategy.
     *
     * @param switchStrategy the switchStrategy to set
     */
    public void setSwitchStrategy(Integer switchStrategy) {
        this.switchStrategy = switchStrategy;
    }

    public String getTagName() {
        return tagName;
    }

    public void setTagName(String tagName) {
        this.tagName = tagName;
    }

    /**
     * To string.
     *
     * @return the string
     */
    @Override
    public String toString() {
        return ToStringBuilder.reflectionToString(this);
    }

}
